@@ -1,10 +1,21 @@
 =head1 NAME
 
-Postgres::Handler - Accessors for PostgreSQL data 
+Postgres::Handler - Builds upon DBD::Pg for advanced CGI web apps
 
 =head1 DESCRIPTION
 
-Accessors for PostgreSQL data.  Simplifies data access through a series of standard class methods.
+Postgres::Handler builds upon the foundation set by
+DBI and DBD::Pg to create a superset of methods for tying together
+some of the basic interface concepts of DB management when used
+in a web server environment. Postgres::Handler is meant to build 
+upon the strengths of DBD::Pg and DBI and add common usability 
+features for a variety of Internet applications.
+
+Postgres::Handler encapsulates error message handling, information
+message handling, simple caching of requests through a complete
+iteration of a server CGI request.  You will also find some key
+elements that hook the CGI class to the DBI class to simplify
+data IO to & from web forms and dynamic pages.
 
 =head1 SYNOPSIS
 
@@ -112,8 +123,8 @@ use constant cPGNoRecs	=> '0E0';
 =cut
 #==============================================================================
 
-our $VERSION 				= 1.8;							# Set our version
-our $BUILD					= '2006-01-24 23:20';		# BUILD
+our $VERSION 				= 1.9;							# Set our version
+our $BUILD					= '2006-02-08 23:20';		# BUILD
 
 struct (
 		dbname	=> '$',
@@ -457,6 +468,9 @@ sub DoLE {
 
  The value of the field.
 
+ Returns 0 and lasterror() is set to a value if an error occurs
+               lasterror() is blank if there was no error
+
 =item Example
 
  my $objPGDATA = new Postgres::Handler::HTML ('mytable!PGHkeyfld' => 'id');
@@ -508,11 +522,14 @@ sub Field {
 				if (($options{KEY} && ($options{KEY} ne ($self->data("$table!key") || ''))) || ($options{WHERE} ne '')) {
 
 					my $where = (($options{WHERE} ne '') ? qq[WHERE $options{WHERE}] : 'WHERE ' . $self->data("$table!PGHkeyfld") . qq[ = $options{KEY}]);
-					$self->PrepLEX( -cmd => qq[SELECT * FROM $table $where], -name => "$table!PGHfield" );
-					$self->data("$table!PGHfhr", $self->GetRecord("$table!PGHfield"));
-					if ($self->data("$table!PGHfhr")) {
-						my $keyfld = uc($self->data("$table!PGHkeyfld"));
-						$self->data("$table!key", $self->data("$table!PGHfhr")->{$keyfld});
+					$retval = $self->PrepLEX( -cmd => qq[SELECT * FROM $table $where], -name => "$table!PGHfield" );
+					if ($retval) {
+						$self->data(ERRMSG,'');
+						$self->data("$table!PGHfhr", $self->GetRecord("$table!PGHfield"));
+						if ($self->data("$table!PGHfhr")) {
+							my $keyfld = uc($self->data("$table!PGHkeyfld"));
+							$self->data("$table!key", $self->data("$table!PGHfhr")->{$keyfld});
+						}
 					}
 				}		
 			}		
@@ -1011,6 +1028,11 @@ __END__
 
 =head1 REVISION HISTORY
 
+ v1.9 - Feb 2006
+      Update Field() to prevent SIGV error when WHERE clause causes error on statement
+		Field() now returns 0 + lasterror() set to value if failed execute
+		            returns fldval + lasterror() is blank if execution OK
+
  v1.8 - Jan 2006
       Bug fix on PrepLE and PrepLEX for perl -w compatability
 		Added DoLE param to return error status (0) if the command affects 0 records '0E0'
